#ifndef _PFE_UTILS_SUB_H
#define _PFE_UTILS_SUB_H 1063198933
/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/utils-sub.c */

#include <pfe/pfe-sub.h>

#ifdef __cplusplus
extern "C" {
#endif




_extern  void p4_delay (int ms) ; /*{*/

#ifdef __cplusplus
} /* extern "C" */
#endif


#endif
